Index: src/fortranscanner.l
===================================================================
--- src/fortranscanner.l	(revision 616)
+++ src/fortranscanner.l	(working copy)
@@ -138,6 +146,7 @@
 static QCString          argType;  // fortran type of an argument of a parameter list
 static QCString          argName;  // last identifier name in variable list
 static QCString          initializer;  // initial value of a variable
+static int               initializerScope;  // number if nested array scopes in initializer
 static QCString          useModuleName;  // name of module in the use statement
 static Protection        defaultProtection;
 
@@ -159,7 +168,7 @@
 static void scanner_abort();
 
 static void startScope(Entry *scope);
-static bool endScope(Entry *scope);
+static bool endScope(Entry *scope, bool isGlobalRoot=FALSE);
 static QCString getFullName(Entry *e);
 static bool isTypeName(QCString name);
 static void resolveModuleProcedures(QList<Entry> &moduleProcedures, Entry *current_root);
@@ -226,6 +238,8 @@
@@ -530,19 +571,26 @@
 <Variable>{COMMA}	                {}
 <Variable>{BS}"="                       { yy_push_state(YY_START);
                                           initializer="";
+                                          initializerScope = 0;
 					  BEGIN(Initialization);
                                         }
 <Variable>"\n"	                        { currentModifiers = SymbolModifiers();
                                           yy_pop_state(); // end variable deklaration list
                                           yyLineNr++; yyLineNr+=lineCountPrepass; lineCountPrepass=0;
                                           docBlock.resize(0);
                                         }
 
-<Initialization>"("                     { initializer+=yytext; 
-                                          BEGIN(ArrayInitializer); // initializer may contain comma
+<Initialization,ArrayInitializer>"(/"   { initializer+=yytext;
+                                           initializerScope++;
+                                           BEGIN(ArrayInitializer); // initializer may contain comma
                                         }
-<ArrayInitializer>")"                   { initializer+=yytext;
-                                          BEGIN(Initialization);
+<ArrayInitializer>"/)"                   { initializer+=yytext;
+                                           initializerScope--;
+                                           if(initializerScope<=0)
+                                           {
+                                              initializerScope = 0; // just in case
+                                              BEGIN(Initialization);
+                                           }
                                         }
 <ArrayInitializer>.                     { initializer+=yytext; }
 <Initialization>{COMMA}                 { yy_pop_state(); // end initialization
@@ -973,10 +1093,10 @@
 /*! Ends scope in fortran program: may update subprogram arguments or module variable attributes.
  * \see startScope()
  */
-static bool endScope(Entry *scope) 
+static bool endScope(Entry *scope, bool isGlobalRoot)
 {
   //cout<<"end scope: "<<scope->name<<endl;
-  if (current_root->parent())
+  if (current_root->parent() || isGlobalRoot)
   {
     current_root= current_root->parent(); /* end substructure */
   }
@@ -1245,7 +1368,7 @@
     yyFileName = fileName;
     msg("Parsing file %s...\n",yyFileName.data());
 
-    current_root  = rt ;
+    startScope(rt); // implies current_root = rt
     initParser();
     groupEnterFile(yyFileName,yyLineNr);
 
@@ -1264,6 +1387,8 @@
     fscanYYlex();
     groupLeaveFile(yyFileName,yyLineNr);
 
+    endScope(current_root, TRUE); // TRUE - global root
+
     //debugCompounds(rt); //debug 
 
     rt->program.resize(0);
